@@ -2,5 +2,5 @@ expect_df_equal <- function(x, y) {
   row.names(x) <- NULL
   row.names(y) <- NULL
 
-  expect_equal(x, y)
+  expect_equivalent(x, y)
 }
